<?php

namespace Simpler\Models;

final class Order
{
    /**
     * @var string
     */
    private $simpler_cart_id;
    /**
     * @var string
     */
    private $currency;
    /**
     * @var array
     */
    private $cart;
    /**
     * @var string
     */
    private $coupon;
    /**
     * @var int
     */
    private $shipping_method_id;

    /**
     * @var OrderShipping
     */
    private $shipping;

    public function __construct($simpler_cart_id, $currency, $shipping_method_id, $shipping, $coupon, array $cart)
    {
        $this->simpler_cart_id    = $simpler_cart_id;
        $this->currency           = $currency;
        $this->shipping_method_id = $shipping_method_id;
        $this->shipping           = $shipping;
        $this->coupon             = $coupon;
        $this->cart               = $cart;
    }

    public static function from_json(array $json)
    {
        $items = array_map(function ($el) {
            return CartItem::from_json($el);
        }, $json['cart']);

        $shipping = NULL;
        if (isset($json['shipping'])) {
            $shipping = OrderShipping::from_json($json['shipping']);
        }
        return new Order(
            $json['simpler_cart_id'],
            $json['currency'],
            $json['shipping_method_id'] ?? NULL,
            $shipping,
            $json['coupon'] ?? NULL,
            $items
        );
    }

    public function get_simpler_cart_id()
    {
        return $this->simpler_cart_id;
    }

    public function get_currency()
    {
        return $this->currency;
    }

    public function get_shipping_method_id()
    {
        return $this->shipping_method_id;
    }

    public function get_shipping()
    {
        return $this->shipping;
    }

    public function get_coupon()
    {
        return $this->coupon;
    }

    public function get_cart()
    {
        return $this->cart;
    }
}
